<?php

namespace Fastrack\Contact;

use Fastrack\Property\Property;
use Fastrack\Property\Restaurant;
use Silverstripe\ORM\DataObject;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;
use SilverStripe\SiteConfig\SiteConfig;

class ClosedDay extends DataObject implements PermissionProvider
{
	
	private static $table_name = 'closed_day';
	
	private static $db = [
		'DayDescription' => 'Varchar',
		'Date' => 'Date',
		'Recurring' => 'Boolean',
		'SortOrder' => 'Int'
	];

	private static $has_one = [
		'Property' => Property::class,
		'Restaurant' => Restaurant::class,
		'SiteConfig' => SiteConfig::class,
	];

	private static $default_sort = 'SortOrder';

	public function getCMSFields()
	{
		$fields = parent::getCMSFields();
		$fields->removeByName('SortOrder');
		return $fields;
	}

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_CLOSED_DAYS' => [
				'name' => 'Manage closed days',
				'category' => 'Properties',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		return Permission::check(['MANAGE_CLOSED_DAYS']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_CLOSED_DAYS']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_CLOSED_DAYS']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_CLOSED_DAYS']);
	}

}
