<?php

namespace Fastrack\Contact;

use SilverStripe\Forms\GridField\GridField;
use SilverStripe\Forms\GridField\GridFieldAddExistingAutocompleter;
use SilverStripe\Forms\GridField\GridFieldConfig_RelationEditor;
use SilverStripe\Forms\GridField\GridFieldDataColumns;
use SilverStripe\Forms\GridField\GridFieldDeleteAction;
use SilverStripe\Forms\HeaderField;
use SilverStripe\Forms\TextField;

use SilverStripe\Forms\HTMLEditor\HTMLEditorField;
use SilverStripe\Forms\FieldList;
use SilverStripe\ORM\ArrayList;
use SilverStripe\ORM\DataExtension;
use UndefinedOffset\SortableGridField\Forms\GridFieldSortableRows;

class ContactExtension extends DataExtension
{

	private static $db = [
		'Email' => 'Varchar(255)',
		'ContactFormEmail' => 'Varchar(255)',
		'Phone' => 'Varchar(255)',
		'AfterHoursPhone' => 'Varchar(255)',
		'InternationalPhone' => 'Varchar(255)',
		'FreeCallPhone' => 'Varchar(255)',
		'MobilePhone' => 'Varchar(255)',
		'Fax' => 'Varchar(255)',
		'Facebook' => 'Varchar(255)',
		'Twitter' => 'Varchar(255)',
		'GooglePlus' => 'Varchar(255)',
		'Instagram' => 'Varchar(255)',
		'Youtube' => 'Varchar(255)',
		'LinkedIn' => 'Varchar(255)',
	];

	private static $has_many = [
		'OpeningHours' => OpeningHour::class,
		'ClosedDays' => ClosedDay::class
	];

	public function updateCMSFields(FieldList $fields)
	{
		$fields->addFieldsToTab('Root.Contact', [
			HeaderField::create('EmailHeader', 'Email'),
			TextField::create('Email', 'Email'),
			TextField::create('ContactFormEmail', 'Email for contact form'),

			HeaderField::create('PhoneHeader', 'Phone'),
			TextField::create('Phone', 'Phone'),
			TextField::create('AfterHoursPhone', 'After hours phone'),
			TextField::create('InternationalPhone', 'International phone'),
			TextField::create('FreeCallPhone', 'Free call phone'),
			TextField::create('MobilePhone', 'Mobile phone'),
			TextField::create('Fax', 'Fax'),

			HeaderField::create('SocialMediaHeader', 'Social media'),
			TextField::create('Facebook', 'Facebook link'),
			TextField::create('Twitter', 'Twitter link'),
			TextField::create('GooglePlus', 'Google Plus link'),
			TextField::create('Instagram', 'Instagram link'),
			TextField::create('Youtube', 'Youtube link'),
			TextField::create('LinkedIn', 'LinkedIn link'),
		]);

		$fields->removeByName('OpeningHours');
		$fields->removeByName('ClosedDays');

		$fields->addFieldsToTab('Root.Contact', [
			$this->getOpeningHoursGridField(),
			$this->getClosedDaysGridField()
		]);

	}



	private function getOpeningHoursGridField()
	{
		$openingHoursConfiguration = GridFieldConfig_RelationEditor::create(7);
		$openingHoursConfiguration->removeComponentsByType(GridFieldAddExistingAutocompleter::class);
		$openingHoursConfiguration->removeComponentsByType(GridFieldDeleteAction::class);
		$openingHoursConfiguration->addComponent(new GridFieldSortableRows('SortOrder'));
		$openingHoursConfiguration->addComponent(new GridFieldDeleteAction(false));
		$openingHoursGridField = new GridField(
			'OpeningHours', 'Opening Hours', $this->owner->OpeningHours(), $openingHoursConfiguration);

		$openingHoursColumns = $openingHoursGridField
			->getConfig()->getComponentByType(GridFieldDataColumns::class);
		$openingHoursColumns->setDisplayFields([
			'Day' => 'Day',
			'Opening' => 'Opening',
			'Closing' => 'Closing',
			'IsClosed' => 'Is closed'
		]);
		$openingHoursColumns->setFieldCasting([
			'Opening' => 'Time->Nice',
			'Closing' => 'Time->Nice',
			'IsClosed' => 'Boolean->Nice'
		]);
		return $openingHoursGridField;
	}

	private function getClosedDaysGridField()
	{
		$closedDaysConfiguration = GridFieldConfig_RelationEditor::create(4);
		$closedDaysConfiguration->removeComponentsByType(GridFieldAddExistingAutocompleter::class);
		$closedDaysConfiguration->removeComponentsByType(GridFieldDeleteAction::class);
		$closedDaysConfiguration->addComponent(new GridFieldSortableRows('SortOrder'));
		$closedDaysConfiguration->addComponent(new GridFieldDeleteAction(false));
		$closedDaysGridField = new GridField(
			'ClosedDays', 'Closed Days', $this->owner->ClosedDays(), $closedDaysConfiguration);

		$closedDaysColumns = $closedDaysGridField
			->getConfig()->getComponentByType(GridFieldDataColumns::class);
		$closedDaysColumns->setDisplayFields(array(
			'DayDescription' => 'Day description',
			'Date' => 'Date',
			'Recurring' => 'Is recurring'
		));
		$closedDaysColumns->setFieldCasting(array(
			'Date' => 'Date->Nice',
			'Recurring' => 'Boolean->Nice'
		));
		return $closedDaysGridField;
	}


	public function getGroupedOpeningHours()
	{
		$openingHours = new OpeningHours();
		foreach ($this->owner->OpeningHours() as $openingHour) {
			$openingHours->add($openingHour);
		}
		return $openingHours->getGroupedOpeningHours();
	}

}
