<?php

namespace Fastrack\Contact;

use Fastrack\Property\Property;
use Fastrack\Property\Restaurant;
use Fastrack\Utilities\ModelUtilities;
use SilverStripe\ORM\DataObject;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;
use SilverStripe\SiteConfig\SiteConfig;

class OpeningHour extends DataObject implements PermissionProvider
{

	private static $table_name = 'opening_hour';

	private static $db = [
		'Label' => 'Varchar',
		'Day' => 'Enum(array("Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"))',
		'Opening' => 'Time',
		'Closing' => 'Time',
		'IsClosed' => 'Boolean',
		'SortOrder' => 'Int',
	];

	private static $has_one = [
		'SiteConfig' => SiteConfig::class,
		'Property' => Property::class,
		'Restaurant' => Restaurant::class,
	];

	private static $default_sort = 'SortOrder';

	private static $translate = [
	    'Label',
	];

	public function getCMSFields()
	{
		$fields = parent::getCMSFields();
		$fields->removeByName('SortOrder');
		ModelUtilities::hideHasOneFields($this, $fields);
		return $fields;
	}

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_OPENING_HOURS' => [
				'name' => 'Manage opening hours',
				'category' => 'Properties',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		return Permission::check(['MANAGE_OPENING_HOURS']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_OPENING_HOURS']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_OPENING_HOURS']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_OPENING_HOURS']);
	}

}
