<?php

namespace Fastrack\Contact;

use SilverStripe\ORM\ArrayList;
use SilverStripe\ORM\FieldType\DBField;
use SilverStripe\ORM\FieldType\DBTime;
use SilverStripe\View\ArrayData;

class OpeningHours
{

	/**
	 * @var ArrayList
	 */
	private $groups;

	private $daysOfWeek = [
		'monday',
		'tuesday',
		'wednesday',
		'thursday',
		'friday',
		'saturday',
		'sunday',
	];

	public function __construct()
	{
		$this->groups = new ArrayList();
	}



	public function add(OpeningHour $openingHour)
	{
		$group = $this->getGroup($openingHour->getField('Label'));
		if ($group) {
			$day = $this->getDay($group, $openingHour);
			if ($day) {
				$day->getField('Days')->push($openingHour->getField('Day'));
			} else {
				$group->getField('Days')->push($this->createDay($openingHour));
			}
		} else {
			$this->groups->push(new ArrayData([
				'Label' => $openingHour->getField('Label'),
				'Days' => new ArrayList([$this->createDay($openingHour)]),
			]));
		}
	}



	public function getGroupedOpeningHours()
	{
		$this->setReadableDays();
		return $this->groups;
	}

	private function getGroup($label)
	{
		foreach ($this->groups as $group) {
			if ($group->getField('Label') === $label) {
				return $group;
			}
		}
		return null;
	}

	private function getDay($group, $openingHour)
	{
		foreach ($group->getField('Days') as $day) {
			if ($openingHour->getField('IsClosed') == $day->getField('IsClosed')) {
				return $day;
			}
			if ($day->getField('Opening') == $openingHour->getField('Opening')) {
				if ($day->getField('Closing') == $openingHour->getField('Closing')) {
					return $day;
				}
			}
		}
		return null;
	}

	private function createDay($openingHour)
	{
		return new ArrayData([
			'Days' => new ArrayList([$openingHour->getField('Day')]),
			'ReadableDays' => '',
			'Opening' => DBTime::create('Opening')->setValue($openingHour->Opening),
			'Closing' => DBTime::create('Opening')->setValue($openingHour->Closing),
			'IsClosed' => $openingHour->getField('IsClosed') ? true : false,
		]);
	}

	private function setReadableDays()
	{
		foreach ($this->groups as $group) {
			foreach ($group->getField('Days') as $day) {
				$days = $day->getField('Days')->toArray();
				usort($days, function ($a, $b) {
					$indexA = array_search(strtolower($a), $this->daysOfWeek);
					$indexB = array_search(strtolower($b), $this->daysOfWeek);
					if ($indexA === false || $indexB === false) {
						return 0;
					}
					return ($indexA < $indexB) ? -1 : 1;
				});
				$readable = implode(', ', $days);
				$readableLower = strtolower($readable);
				switch ($readableLower) {
                    case 'monday, tuesday, wednesday, thursday, friday, saturday, sunday':
                        $readable = 'Monday to Sunday';
                        break;
                    case 'monday, tuesday, wednesday, thursday, friday':
                        $readable = 'Monday to Friday';
                        break;
                    case 'saturday, sunday':
                        $readable = 'Weekends';
                        break;
                }
				$day->setField('ReadableDays', $readable);
			}
		}
	}
}
